# libcollection
common data structures

[![PyPI version](https://badge.fury.io/py/jx-libcollection.svg)](https://badge.fury.io/py/jx-libcollection)


## stack

* ResizingArrayStack
* LinkedStack

## queue

* LinkedQueue
